@@ -2,14 +2,19 @@
 # This file is part of ruby-ffi.
 # For licensing, see LICENSE.SPECS
 #
+
 require File.expand_path(File.join(File.dirname(__FILE__), "spec_helper"))
 require 'delegate'
-require 'java' if RUBY_PLATFORM =~ /java/
 
 module PointerTestLib
   extend FFI::Library
   ffi_lib TestLibrary::PATH
-  attach_function :ptr_ret_int32_t, [ :pointer, :int ], :int
+  begin
+    attach_function :ptr_ret_int32_t, [ :pointer, :int ], :int
+  rescue FFI::NotFoundError
+    # NetBSD uses #define instead of typedef for these
+    attach_function :ptr_ret_int32_t, :ptr_ret___int32_t, [ :pointer, :int ], :int
+  end
   attach_function :ptr_from_address, [ FFI::Platform::ADDRESS_SIZE == 32 ? :uint : :ulong_long ], :pointer
   attach_function :ptr_set_pointer, [ :pointer, :int, :pointer ], :void
   attach_function :ptr_ret_pointer, [ :pointer, :int ], :pointer
@@ -24,12 +29,13 @@ describe "Pointer" do
       @ptr
     end
   end
+
   it "Any object implementing #to_ptr can be passed as a :pointer parameter" do
     memory = FFI::MemoryPointer.new :long_long
     magic = 0x12345678
     memory.put_int32(0, magic)
     tp = ToPtrTest.new(memory)
-    PointerTestLib.ptr_ret_int32_t(tp, 0).should == magic
+    expect(PointerTestLib.ptr_ret_int32_t(tp, 0)).to eq(magic)
   end
   class PointerDelegate < DelegateClass(FFI::Pointer)
     def initialize(ptr)
@@ -39,18 +45,21 @@ describe "Pointer" do
       @ptr
     end
   end
+
   it "A DelegateClass(Pointer) can be passed as a :pointer parameter" do
     memory = FFI::MemoryPointer.new :long_long
     magic = 0x12345678
     memory.put_int32(0, magic)
     ptr = PointerDelegate.new(memory)
-    PointerTestLib.ptr_ret_int32_t(ptr, 0).should == magic
+    expect(PointerTestLib.ptr_ret_int32_t(ptr, 0)).to eq(magic)
   end
+
   it "Fixnum cannot be used as a Pointer argument" do
-    lambda { PointerTestLib.ptr_ret_int32(0, 0) }.should raise_error
+    expect { PointerTestLib.ptr_ret_int32(0, 0) }.to raise_error
   end
+
   it "Bignum cannot be used as a Pointer argument" do
-    lambda { PointerTestLib.ptr_ret_int32(0xfee1deadbeefcafebabe, 0) }.should raise_error
+    expect { PointerTestLib.ptr_ret_int32(0xfee1deadbeefcafebabe, 0) }.to raise_error
   end
 
   describe "pointer type methods" do
@@ -58,13 +67,13 @@ describe "Pointer" do
     it "#read_pointer" do
       memory = FFI::MemoryPointer.new :pointer
       PointerTestLib.ptr_set_pointer(memory, 0, PointerTestLib.ptr_from_address(0xdeadbeef))
-      memory.read_pointer.address.should == 0xdeadbeef
+      expect(memory.read_pointer.address).to eq(0xdeadbeef)
     end
 
     it "#write_pointer" do
       memory = FFI::MemoryPointer.new :pointer
       memory.write_pointer(PointerTestLib.ptr_from_address(0xdeadbeef))
-      PointerTestLib.ptr_ret_pointer(memory, 0).address.should == 0xdeadbeef
+      expect(PointerTestLib.ptr_ret_pointer(memory, 0).address).to eq(0xdeadbeef)
     end
 
     it "#read_array_of_pointer" do
@@ -75,7 +84,7 @@ describe "Pointer" do
       end
       array = memory.read_array_of_pointer(values.size)
       values.each_with_index do |address, j|
-        array[j].address.should == address
+        expect(array[j].address).to eq(address)
       end
     end
     
@@ -84,23 +93,23 @@ describe "Pointer" do
   describe 'NULL' do
     it 'should be obtained using Pointer::NULL constant' do
       null_ptr = FFI::Pointer::NULL
-      null_ptr.null?.should be_true
+      expect(null_ptr).to be_null
     end
     it 'should be obtained passing address 0 to constructor' do
-      FFI::Pointer.new(0).null?.should be_true
+      expect(FFI::Pointer.new(0)).to be_null
     end
     it 'should raise an error when attempting read/write operations on it' do
       null_ptr = FFI::Pointer::NULL
-      lambda { null_ptr.read_int }.should raise_error(FFI::NullPointerError)
-      lambda { null_ptr.write_int(0xff1) }.should raise_error(FFI::NullPointerError)
+      expect { null_ptr.read_int }.to raise_error(FFI::NullPointerError)
+      expect { null_ptr.write_int(0xff1) }.to raise_error(FFI::NullPointerError)
     end
     it 'returns true when compared with nil' do
-      (FFI::Pointer::NULL == nil).should be_true
+      expect((FFI::Pointer::NULL == nil)).to be true
     end
   end
 
   it "Pointer.size returns sizeof pointer on platform" do
-    FFI::Pointer.size.should == (FFI::Platform::ADDRESS_SIZE / 8)
+    expect(FFI::Pointer.size).to eq((FFI::Platform::ADDRESS_SIZE / 8))
   end
 
   describe "#slice" do
@@ -111,22 +120,22 @@ describe "Pointer" do
     end
 
     it "contents of sliced pointer matches original pointer at offset" do
-      @mptr.slice(4, 4).get_uint(0).should == 0xdeadbeef
+      expect(@mptr.slice(4, 4).get_uint(0)).to eq(0xdeadbeef)
     end
 
     it "modifying sliced pointer is reflected in original pointer" do
       @mptr.slice(4, 4).put_uint(0, 0xfee1dead)
-      @mptr.get_uint(4).should == 0xfee1dead
+      expect(@mptr.get_uint(4)).to eq(0xfee1dead)
     end
 
     it "access beyond bounds should raise IndexError" do
-      lambda { @mptr.slice(4, 4).get_int(4) }.should raise_error(IndexError)
+      expect { @mptr.slice(4, 4).get_int(4) }.to raise_error(IndexError)
     end
   end
 
   describe "#type_size" do
     it "should be same as FFI.type_size(type)" do
-      FFI::MemoryPointer.new(:int, 1).type_size.should == FFI.type_size(:int)
+      expect(FFI::MemoryPointer.new(:int, 1).type_size).to eq(FFI.type_size(:int))
     end
   end
 end
@@ -160,8 +169,9 @@ describe "AutoPointer" do
   class AutoPointerSubclass < FFI::AutoPointer
     def self.release(ptr); end
   end
+
   it "cleanup via default release method" do
-    AutoPointerSubclass.should_receive(:release).at_least(loop_count-wiggle_room).times
+    expect(AutoPointerSubclass).to receive(:release).at_least(loop_count-wiggle_room).times
     AutoPointerTestHelper.reset
     loop_count.times do
       # note that if we called
@@ -181,7 +191,7 @@ describe "AutoPointer" do
     #
     #  we'd have a reference to the pointer and it would
     #  never get GC'd.
-    AutoPointerTestHelper.should_receive(:release).at_least(loop_count-wiggle_room).times
+    expect(AutoPointerTestHelper).to receive(:release).at_least(loop_count-wiggle_room).times
     AutoPointerTestHelper.reset
     loop_count.times do
       FFI::AutoPointer.new(PointerTestLib.ptr_from_address(magic),
@@ -191,7 +201,7 @@ describe "AutoPointer" do
   end
 
   it "cleanup when passed a method" do
-    AutoPointerTestHelper.should_receive(:release).at_least(loop_count-wiggle_room).times
+    expect(AutoPointerTestHelper).to receive(:release).at_least(loop_count-wiggle_room).times
     AutoPointerTestHelper.reset
     loop_count.times do
       FFI::AutoPointer.new(PointerTestLib.ptr_from_address(magic),
@@ -201,7 +211,7 @@ describe "AutoPointer" do
   end
 
   it "can be used as the return type of a function" do
-    lambda do
+    expect do
       Module.new do
         extend FFI::Library
         ffi_lib TestLibrary::PATH
@@ -210,18 +220,18 @@ describe "AutoPointer" do
         end
         attach_function :ptr_from_address, [ FFI::Platform::ADDRESS_SIZE == 32 ? :uint : :ulong_long ], CustomAutoPointer
       end
-    end.should_not raise_error
+    end.not_to raise_error
   end
 
   describe "#new" do
     it "MemoryPointer argument raises TypeError" do
-      lambda { FFI::AutoPointer.new(FFI::MemoryPointer.new(:int))}.should raise_error(::TypeError)
+      expect { FFI::AutoPointer.new(FFI::MemoryPointer.new(:int))}.to raise_error(::TypeError)
     end
     it "AutoPointer argument raises TypeError" do
-      lambda { AutoPointerSubclass.new(AutoPointerSubclass.new(PointerTestLib.ptr_from_address(0))) }.should raise_error(::TypeError)
+      expect { AutoPointerSubclass.new(AutoPointerSubclass.new(PointerTestLib.ptr_from_address(0))) }.to raise_error(::TypeError)
     end
     it "Buffer argument raises TypeError" do
-      lambda { FFI::AutoPointer.new(FFI::Buffer.new(:int))}.should raise_error(::TypeError)
+      expect { FFI::AutoPointer.new(FFI::Buffer.new(:int))}.to raise_error(::TypeError)
     end
 
   end
@@ -232,13 +242,13 @@ describe "AutoPointer" do
     end
 
     it "should be true by default" do
-      ptr_class.new(FFI::Pointer.new(0xdeadbeef)).autorelease?.should be_true
+      expect(ptr_class.new(FFI::Pointer.new(0xdeadbeef)).autorelease?).to be true
     end
 
     it "should return false when autorelease=(false)" do
       ptr = ptr_class.new(FFI::Pointer.new(0xdeadbeef))
       ptr.autorelease = false
-      ptr.autorelease?.should be_false
+      expect(ptr.autorelease?).to be false
     end
   end
 
@@ -249,7 +259,7 @@ describe "AutoPointer" do
 
     it "type_size of AutoPointer should match wrapped Pointer" do
       aptr = ptr_class.new(FFI::Pointer.new(:int, 0xdeadbeef))
-      aptr.type_size.should == FFI.type_size(:int)
+      expect(aptr.type_size).to eq(FFI.type_size(:int))
     end
     
     it "[] offset should match wrapped Pointer" do
@@ -257,8 +267,8 @@ describe "AutoPointer" do
       aptr = ptr_class.new(FFI::Pointer.new(:int, mptr))
       aptr[0].write_uint(0xfee1dead)
       aptr[1].write_uint(0xcafebabe)
-      mptr[0].read_uint.should == 0xfee1dead
-      mptr[1].read_uint.should == 0xcafebabe
+      expect(mptr[0].read_uint).to eq(0xfee1dead)
+      expect(mptr[1].read_uint).to eq(0xcafebabe)
     end
   end
 end
